==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebGroupByRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowTemplateContextDescription } from "./WebGroupByRowTemplateContextDescription";
/**
 * @hidden
 */
export let WebGroupByRowTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowTemplateContextDescriptionMetadata.a == null) {
                WebGroupByRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowTemplateContextDescriptionMetadata.c(WebGroupByRowTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGroupByRowTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGroupByRowTemplateContextDescriptionMetadata.a);
            WebGroupByRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebGroupByRecord");
        }
        static d(a) {
            WebGroupByRowTemplateContextDescriptionMetadata.b(a);
            a.ad("WebGroupByRowTemplateContext", () => new WebGroupByRowTemplateContextDescription());
            a.ac("WebGroupByRowTemplateContext", WebGroupByRowTemplateContextDescriptionMetadata.a);
        }
    }
    WebGroupByRowTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByRowTemplateContextDescriptionMetadata, 'WebGroupByRowTemplateContextDescriptionMetadata');
    WebGroupByRowTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebGroupByRowTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRecordDescriptionMetadata } from "./WebGroupByRecordDescriptionMetadata";
import { WebGroupByRowTemplateContextDescription } from "./WebGroupByRowTemplateContextDescription";
/**
 * @hidden
 */
export let WebGroupByRowTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowTemplateContextDescriptionMetadata.a == null) {
                WebGroupByRowTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowTemplateContextDescriptionMetadata.c(WebGroupByRowTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGroupByRowTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGroupByRowTemplateContextDescriptionMetadata.a);
            WebGroupByRecordDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebGroupByRecord");
        }
        static d(a) {
            WebGroupByRowTemplateContextDescriptionMetadata.b(a);
            a.ae("WebGroupByRowTemplateContext", () => new WebGroupByRowTemplateContextDescription());
            a.ad("WebGroupByRowTemplateContext", WebGroupByRowTemplateContextDescriptionMetadata.a);
        }
    }
    WebGroupByRowTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByRowTemplateContextDescriptionMetadata, 'WebGroupByRowTemplateContextDescriptionMetadata');
    WebGroupByRowTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextDescriptionMetadata;
})();
